@@ -1,3 +1,5 @@
+
+
 GaussRF = function(x,param=c(variance=1, range=1, rough=1), ...) {
 	UseMethod("GaussRF")
 	
@@ -5,15 +7,15 @@ GaussRF = function(x,param=c(variance=1, range=1, rough=1), ...) {
 
 GaussRF.Raster = function(x,param=c(variance=1, range=1, rough=1), ...){
 
-	xseq = seq(x@extent@xmin, x@extent@xmax, len=x@ncols)
-	yseq = seq(x@extent@ymin, x@extent@ymax, len=x@nrows)
-
+	xseq = c(xmin(x)+xres(x)/2, xmax(x)-xres(x)/2, xres(x))
+	yseq = c(ymin(x)+yres(x)/2, ymax(x)-yres(x)/2, yres(x))
+	
  	
 	
 	
 	res = GaussRF(x=xseq, param=param,
-			y=yseq,	grid=TRUE, 
-		...
+			y=yseq,	grid=TRUE, gridtriple=TRUE,
+			...
 			)
 
 			
@@ -52,39 +54,17 @@ GaussRF.default = function(x,param=c(variance=1, range=1, rough=1),  ...){
 			warning("param has names", paste(names(param),collapse=","), 
 					" must have ", paste(requiredParams, collapse=","))
 
-		param["scaleRandomFields"] = param["range"]/2 
 		
-		if(any(names(param)=="aniso.ratio")){
-			# geometric anisotropy
-			if(any(names(param)=="aniso.angle.degrees") & 
-					!any(names(param)=="aniso.angle.radians") ) {
-				param["aniso.angle.radians"] = param["aniso.angle.degrees"]*2*pi/360				
-		}
+		model  = modelRandomFields(param)
 		
-		scaleTwoDirections = c(1/param["scaleRandomFields"],
-				1/(param["aniso.ratio"]*param["scaleRandomFields"]))
-		angle = param["aniso.angle.radians"]
-		anisoMat = diag(scaleTwoDirections) %*% 
-				matrix(c(cos(angle), sin(angle), 
-								-sin(angle), cos(angle)),2)
-		
-		
-			model=list("$", var=param["variance"],   
-					A=anisoMat,
-				list("matern", nu=param["rough"]))	
-		} else {
-		
-			model=list("$", var=param["variance"],   
-					s=param["scaleRandomFields"],
-					list("matern", nu=param["rough"]))	
-			
-		}	
 		theArgs$model = model	
 	} else {
 		if(!is.list(theArgs$model)) # if model is a list, it's the extended model definition which doesnt need the param argument
 			theArgs$param = param
 	}
 	
+ 
+	
 	result = do.call( RandomFields::GaussRF, theArgs)
 
 	# some things break (such as spplot) if I add this as an attribute
