@@ -11,7 +11,7 @@ excFunQQ = function(themat) {
 			themat[over,]
 			)
 	
-	prob = pracma::trapz(toInt[,"x"], toInt[,"y"])
+	prob = trapz(toInt[,"x"], toInt[,"y"])
 } else {
 	prob = NA
 }
@@ -31,7 +31,9 @@ if(length(grep("^Raster", class(template)))) {
 	if(nlayers(template)>1)
 		template = template[[1]]
 	names(excProbAll) = names(marginals)
-	values(template) = c(t(matrix(excProbAll, nrow(template),ncol(template))))
+	values(template) = matrix(excProbAll, 
+							nrow=nrow(template),ncol=ncol(template),
+							byrow=T)
 	excProbAll = template
 	names(excProbAll) = paste("exc", threshold, sep="")
 } 
